@@ -202,6 +202,16 @@ def update_models(all_rest_dict_list):
 
         # managed处理
         if curr_field_name == 'managed' and len(spt) == 3:
+            if curr_class_name not in all_rest_dict_dict:
+                #此class未找到，直接忽略
+                print('django_rest_admin:skip class:', curr_class_name)
+                f2.write(one_line + "\n")
+                continue
+            if 'is_managed' not in all_rest_dict_dict[curr_class_name]:
+                # 此class未找到，直接忽略
+                print('django_rest_admin:skip class2:', curr_class_name)
+                f2.write(one_line + "\n")
+                continue
             curr_param = all_rest_dict_dict[curr_class_name]['is_managed']
             if curr_param=='True':
                 # 不是需要的字段，直接复制
